Example notebooks
=================

.. toctree::
    :maxdepth: 1

    Getting started with Hyrax <pre_executed/train_model>
    Writing a custom dataset <pre_executed/custom_dataset>
    Providing data 1 <notebooks/model_input_1>
    Providing data 2 <notebooks/model_input_2>
    Providing data 3 <notebooks/model_input_3>
    Training to Similarity Search <pre_executed/hsc_train_to_similarity_search>
    Working with a vector database <pre_executed/vector_db_demo>
    Exporting a Model <pre_executed/export_model>
    HyraxQL data requests <pre_executed/hyraxql_demo>
